Privacy

# This website's privacy

Back

## Privacy (english)

Please note that the purpose of the english version is only for a better understanding of our Data Protection Statement. You're agreeing to our Data Protection Statement is based on the german version (see below).

by D9T GmbH, Heilmeyersteige 131, 89075 Ulm, Municipal Court of Ulm, HRB 722416 (hereinafter referred to as “D9T”) as per July 17, 2014

### Why a data protection statement?

D9T GmbH takes the protection of personal data very seriously. We want you to know when we store which data and how we use them. As a company under private law we are subject i.a. to the provisions of the Federal Data Protection Act (BDSG) and the Telemedia Act (TMG). We have taken technical and organizational measures to ensure that the data protection provisions are complied with by us as well as by external service providers.

#### How do we protect your data?

We use extensive security measures to guarantee the security of your confidential data.

We use secure servers and transmit data for sales processing exclusively via an encoded SSL-connection.

We store your data on specially protected servers in Germany. Access to this is only permitted to specially authorized persons subject to data protection dealing with technical, business or editorial management of the servers.

#### What are personal data?

Personal data are individual data on personal or factual situations on a specific or specifiable legal entity and may be used i.a. for determining your identity. This includes information such as your real name, address, mailing address, telephone number.

#### What information and data do we record?

We record personal data if you use our contact forms, register on the site or order our newsletter.

Beyond the data and information expressly stated here we do not record any information not directly in connection with your identity (such as preferred websites or number of users of a site). The other data recorded is not linked to your user profile and are for statistical evaluation purposes only.

You may use our online offer even without disclosing your identity. If you register for one of our personalized services or order a product, we will ask you for your name and other personal information. It is up to you whether you want to enter this data. We will store your data on specially protected servers in Germany. Access to this is only permitted to only a few specially authorized persons subject to data protection dealing with technical, business or editorial management of the servers.

In connection with your access data are stored for securing purposes which may enable identification (e.g. IP-address, date, time and pages viewed). There is no personal use. We reserve the right to the statistical evaluation of anonymous data sets.

We store IP addresses for a maximum period of four weeks. Storage is for reasons of data security in order to guarantee the stability and operational safety of our system.

#### Disclosure of personal information to third parties

We will use your personal information only within D9T and its affiliated companies. In the case of orders such as domain registrations or certification orders we will not disclose your personal data to third parties without your express consent. Where data are disclosed to service providers within the scope of use of the D9T READY-site, they are subject to the BDSG and other legal provisions. To the extent that we are obligated by law or per court order we will disclose your data to the bodies authorized to receive information.

#### Use of cookies

We use “cookies” (small files with configuration information) to maintain the log-in. They help to retain the log-in for several pages. We do not record personal data using cookies. In some areas of our service range we use cookies for implementing the user function and for visitor tracking.

Most browsers are set to automatically accept cookies. However, you can deactivate the storage of cookies or set your browser in such a way that it notifies you as soon as cookies are being transmitted. If you do not accept cookies this could lead to significant restriction of functions and impairment of our service range.

#### Links to other websites

Our online service range includes links to other websites. We cannot control whether the operators of such sites comply with the data protection regulations.

#### How can I check, correct or delete my data?

Pursuant to § 34 and § 6b BDSG, users have the right to receive free information on their personal data that is being stored upon application.

#### Right of Revocation

If you provided personal data for use you can delete them again at any time. Data for invoicing and accounting purposes are not affected by termination or deletion.

You also have the right to correction, blocking and deletion of this personal data. You can have this done yourself via your personal account or in such cases directly contact:

D9T GmbH
info@d9t.de

#### Questions and comments

If you have any questions, suggestions or comments on the topic of data protection please e-mail info@d9t.de. The rapid development of the Internet may occasionally require adjustments of our data protection notice. You will be informed of any changes here.

## Datenschutzerklärung

### Warum eine Datenschutzerklärung?

Die D9T GmbH nimmt den Schutz personenbezogener Daten sehr ernst. Wir möchten, dass Sie wissen, wann wir welche Daten speichern und wie wir sie verwenden. Als privatrechtliches Unternehmen unterliegen wir u.a. den Bestimmungen des Bundesdatenschutzgesetzes (BDSG) und des Telemediengesetzes (TMG). Wir haben technische und organisatorische Maßnahmen getroffen, die sicherstellen, dass die Vorschriften über den Datenschutz sowohl von uns als auch von externen Dienstleistern beachtet werden.

#### Wie schützen wir Ihre Daten?

Wir nutzen umfangreiche Sicherheitsmaßnahmen um die Sicherheit Ihrer vertraulichen Daten zu gewährleisten.

Wir nutzen gesicherte Server und übertragen Daten zur Kaufabwicklung ausschließlich über eine verschlüsselte SSL-Verbindung.

Ihre Angaben speichern wir auf besonders geschützten Servern in Deutschland. Der Zugriff darauf ist nur wenigen besonders befugten und auf den Datenschutz verpflichteten Personen möglich, die mit der technischen, kaufmännischen oder redaktionellen Betreuung der Server befasst sind.

#### Was sind personenbezogene Daten?

Personenbezogene Daten sind Einzelangaben über persönliche oder sachliche Verhältnisse einer bestimmten oder bestimmbaren natürlichen Person und können u.a. dazu genutzt werden, Ihre Identität zu erfahren. Darunter fallen z.B. Informationen wie Ihr richtiger Name, Adresse, Postanschrift, Telefonnummer.

#### Welche Informationen und Daten erheben wir?

Wir erheben persönliche Daten, wenn Sie unser Kontaktformular nutzen oder sich auf den Seiten registrieren oder unseren Newsletter bestellen.

Wir erheben über die hier ausdrücklich erklärten Daten und Informationen keine Informationen, die nicht direkt mit Ihrer Identität in Verbindung gebracht werden (wie zum Beispiel favorisierte Webseiten oder Anzahl der Nutzer einer Site). Die sonst erhobenen Daten sind nicht mit Ihrem Nutzerprofil verknüpft und dienen statistischen Auswertungszwecken.

Sie können unser Online-Angebot auch ohne Offenlegung Ihrer Identität nutzen. Wenn Sie sich für einen unserer personalisierten Dienste registrieren lassen oder ein Produkt bestellen, fragen wir Sie nach Ihrem Namen und nach anderen persönlichen Informationen. Es unterliegt Ihrer freien Entscheidung, ob Sie diese Daten eingeben.

Ihre Angaben speichern wir auf besonders geschützten Servern in Deutschland. Der Zugriff darauf ist nur wenigen besonders befugten und auf den Datenschutz verpflichteten Personen möglich, die mit der technischen, kaufmännischen oder redaktionellen Betreuung der Server befasst sind.

In Verbindung mit Ihrem Zugriff werden auf unseren Servern Daten für Sicherungszwecke gespeichert, die möglicherweise eine Identifizierung zulassen (zum Beispiel IP-Adresse, Datum, Uhrzeit und betrachtete Seiten). Es findet keine personenbezogene Verwertung statt. Die statistische Auswertung anonymisierter Datensätze bleibt vorbehalten.

IP-Adressen speichern wir über einen Zeitraum von maximal vier Wochen. Die Speicherung erfolgt aus Gründen der Datensicherheit, um die Stabilität und die Betriebssicherheit unseres Systems zu gewährleisten.

#### Weitergabe personenbezogener Informationen an Dritte

Wir verwenden Ihre personenbezogenen Informationen nur innerhalb von D9T sowie der verbundenen Unternehmen. Im Fall Ihrer Beauftragungen, z.B. bei Domainregistrierungen oder Zertifikationsbestellungen, geben wir Ihre persönlichen Daten nicht ohne Ihr ausdrückliches Einverständnis an Dritte weiter. Sollten im Rahmen der Nutzung dieser Seite Daten an Dienstleister weitergegeben werden, so sind diese an das BDSG und andere gesetzliche Vorschriften gebunden. Soweit wir gesetzlich oder per Gerichtsbeschluss dazu verpflichtet sind, werden wir Ihre Daten an auskunftsberechtigte Stellen übermitteln.

#### Einsatz von Cookies

Wir setzen "Cookies" (kleine Dateien mit Konfigurationsinformationen) zur Beibehaltung des Logins ein. Sie helfen dabei, dass der Login über mehrere Seiten hinweg erhalten bleibt. Wir erfassen keine personenbezogenen Daten über Cookies.

In einigen Bereichen unseres Angebots verwenden wir Cookies, um Benutzerfunktionen zu realisieren und zum Besuchertracking.

Die meisten Browser sind so eingestellt, dass sie Cookies automatisch akzeptieren. Sie können das Speichern von Cookies jedoch deaktivieren oder Ihren Browser so einstellen, dass er Sie benachrichtigt, sobald Cookies gesendet werden. Wenn Sie keine Cookies akzeptieren, führt dies u.U. zu erheblichen Funktionseinschränkungen und Störungen unseres Angebots.

#### Links zu anderen Websites

Unser Online-Angebot enthält Links zu anderen Websites. Wir haben keinen Einfluss darauf, dass deren Betreiber die Datenschutzbestimmungen einhalten.

#### Wie kann ich meine Daten überprüfen, korrigieren oder löschen?

Gemäß § 34 und § 6b BDSG haben Nutzer das Recht, auf Antrag unentgeltlich Auskunft über die über sie gespeicherten personenbezogenen Daten zu erhalten.

#### Recht auf Widerruf

Wenn Sie uns personenbezogene Daten überlassen haben, können Sie diese jederzeit wieder löschen. Daten für Abrechnungs- und buchhalterische Zwecke sind von einer Kündigung beziehungsweise von einer Löschung nicht berührt.

Sie haben auch das Recht auf Berichtigung, Sperrung und Löschung dieser personenbezogenen Daten. Dies können Sie selbst über Ihren persönlichen Account veranlassen oder Sie wenden sich in all diesen Fällen unmittelbar an:

D9T GmbH
info@d9t.de

#### Fragen und Kommentare

Für Fragen, Anregungen oder Kommentare zum Thema Datenschutz wenden Sie sich bitte per E-Mail an info@d9t.de. Die rasante Entwicklung des Internets macht von Zeit zu Zeit Anpassungen in unserem Datenschutzhinweis erforderlich. Sie werden an dieser Stelle über die Neuerungen informiert.

- GitHub
- Email

- © D9T GmbH
- Imprint
- Privacy
- Design: HTML5 UP